==> ark_15.12.3.orig.tar.xz: ark-15.12.3/plugins/libarchive/kerfuffle_libarchive_readonly.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_libarchive
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_libarchive
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=BSD
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=false
Name=kerfuffle_libarchive_readonly
Name[ar]=kerfuffle_libarchive_readonly
Name[ast]=kerfuffle_libarchive_readonly
Name[bg]=kerfuffle_libarchive_readonly
Name[bs]=kerfuffle_libarchive_readonly
Name[ca]=kerfuffle_libarchive_readonly
Name[ca@valencia]=kerfuffle_libarchive_readonly
Name[cs]=kerfuffle_libarchive_readonly
Name[da]=kerfuffle_libarchive_readonly
Name[de]=kerfuffle_libarchive_readonly
Name[el]=kerfuffle_libarchive_readonly
Name[en_GB]=kerfuffle_libarchive_readonly
Name[es]=kerfuffle_libarchive_readonly
Name[et]=kerfuffle_libarchive_readonly
Name[eu]=kerfuffle_libarchive_readonly
Name[fi]=kerfuffle_libarchive_readonly
Name[fr]=kerfuffle_libarchive_readonly
Name[ga]=kerfuffle_libarchive_readonly
Name[gl]=kerfuffle_libarchive_readonly
Name[hr]=kerfuffle_libarchive_readonly
Name[hu]=kerfuffle_libarchive_readonly
Name[ia]=kerfuffle_libarchive_de_sol_lectura
Name[it]=kerfuffle_libarchive_readonly
Name[ja]=kerfuffle_libarchive_readonly
Name[kk]=kerfuffle_libarchive_readonly
Name[km]=kerfuffle_libarchive_readonly
Name[ko]=kerfuffle_libarchive_readonly
Name[lt]=kerfuffle_libarchive_readonly
Name[lv]=kerfuffle_libarchive_readonly
Name[mr]=कर्फफल_लिब-संग्रह_फक्त वाचण्यासाठी
Name[nb]=kerfuffle_libarchive_readonly
Name[nds]=kerfuffle_libarchive_readonly
Name[nl]=kerfuffle_libarchive_readonly
Name[pa]=kerfuffle_libarchive_readonly
Name[pl]=kerfuffle_libarchive_readonly
Name[pt]=kerfuffle_libarchive_readonly
Name[pt_BR]=kerfuffle_libarchive_readonly
Name[ro]=kerfuffle_libarchive_readonly
Name[ru]=kerfuffle_libarchive_readonly
Name[sk]=kerfuffle_libarchive_readonly
Name[sl]=kerfuffle_libarchive_readonly
Name[sr]=kerfuffle_libarchive_readonly
Name[sr@ijekavian]=kerfuffle_libarchive_readonly
Name[sr@ijekavianlatin]=kerfuffle_libarchive_readonly
Name[sr@latin]=kerfuffle_libarchive_readonly
Name[sv]=Kerfuffle Libarchive skrivskyddat
Name[th]=kerfuffle_libarchive_readonly
Name[tr]=kerfuffle_libarchive_readonly
Name[uk]=kerfuffle_libarchive_readonly
Name[wa]=kerfuffle_libarchive_readonly
Name[x-test]=xxkerfuffle_libarchive_readonlyxx
Name[zh_CN]=kerfuffle_libarchive_readonly
Name[zh_TW]=kerfuffle_libarchive_readonly
MimeType=@SUPPORTED_LIBARCHIVE_READONLY_MIMETYPES@

==> ark-16.04.3.tar.xz: ark-16.04.3/plugins/libarchive/kerfuffle_libarchive_readonly.desktop.cmake <==
[Desktop Entry]
Type=Service
X-KDE-ServiceTypes=Kerfuffle/Plugin
X-KDE-Library=kerfuffle_libarchive_readonly
X-KDE-PluginInfo-Author=Henrique Pinto
X-KDE-PluginInfo-Email=henrique.pinto@kdemail.net
X-KDE-PluginInfo-Name=kerfuffle_libarchive_readonly
X-KDE-PluginInfo-Version=0.0.1
X-KDE-PluginInfo-Website=http://www.kde.org
X-KDE-PluginInfo-License=BSD
X-KDE-Priority=100
X-KDE-Kerfuffle-APIRevision=1
X-KDE-Kerfuffle-ReadWrite=false
Name=kerfuffle_libarchive_readonly
Name[ar]=kerfuffle_libarchive_readonly
Name[ast]=kerfuffle_libarchive_readonly
Name[bg]=kerfuffle_libarchive_readonly
Name[bs]=kerfuffle_libarchive_readonly
Name[ca]=kerfuffle_libarchive_readonly
Name[ca@valencia]=kerfuffle_libarchive_readonly
Name[cs]=kerfuffle_libarchive_readonly
Name[da]=kerfuffle_libarchive_readonly
Name[de]=kerfuffle_libarchive_readonly
Name[el]=kerfuffle_libarchive_readonly
Name[en_GB]=kerfuffle_libarchive_readonly
Name[es]=kerfuffle_libarchive_readonly
Name[et]=kerfuffle_libarchive_readonly
Name[eu]=kerfuffle_libarchive_readonly
Name[fi]=kerfuffle_libarchive_readonly
Name[fr]=kerfuffle_libarchive_readonly
Name[ga]=kerfuffle_libarchive_readonly
Name[gl]=kerfuffle_libarchive_readonly
Name[hr]=kerfuffle_libarchive_readonly
Name[hu]=kerfuffle_libarchive_readonly
Name[ia]=kerfuffle_libarchive_de_sol_lectura
Name[it]=kerfuffle_libarchive_readonly
Name[ja]=kerfuffle_libarchive_readonly
Name[kk]=kerfuffle_libarchive_readonly
Name[km]=kerfuffle_libarchive_readonly
Name[ko]=kerfuffle_libarchive_readonly
Name[lt]=kerfuffle_libarchive_readonly
Name[lv]=kerfuffle_libarchive_readonly
Name[mr]=कर्फफल_लिब-संग्रह_फक्त वाचण्यासाठी
Name[nb]=kerfuffle_libarchive_readonly
Name[nds]=kerfuffle_libarchive_readonly
Name[nl]=kerfuffle_libarchive_readonly
Name[pa]=kerfuffle_libarchive_readonly
Name[pl]=kerfuffle_libarchive_readonly
Name[pt]=kerfuffle_libarchive_readonly
Name[pt_BR]=kerfuffle_libarchive_readonly
Name[ro]=kerfuffle_libarchive_readonly
Name[ru]=kerfuffle_libarchive_readonly
Name[sk]=kerfuffle_libarchive_readonly
Name[sl]=kerfuffle_libarchive_readonly
Name[sr]=kerfuffle_libarchive_readonly
Name[sr@ijekavian]=kerfuffle_libarchive_readonly
Name[sr@ijekavianlatin]=kerfuffle_libarchive_readonly
Name[sr@latin]=kerfuffle_libarchive_readonly
Name[sv]=Kerfuffle Libarchive skrivskyddat
Name[th]=kerfuffle_libarchive_readonly
Name[tr]=kerfuffle_libarchive_readonly
Name[uk]=kerfuffle_libarchive_readonly
Name[wa]=kerfuffle_libarchive_readonly
Name[x-test]=xxkerfuffle_libarchive_readonlyxx
Name[zh_CN]=kerfuffle_libarchive_readonly
Name[zh_TW]=kerfuffle_libarchive_readonly
MimeType=@SUPPORTED_LIBARCHIVE_READONLY_MIMETYPES@
